@@ -25,7 +25,7 @@ def pureDistillation(baseModel, targetModel, path, pathUnlabelled, outputPath, b
 
         # Train base learner
         learn.fine_tune(50, freeze_epochs=2)
-        learn.save(outputPath+os.sep+baseModel)
+        learn.export(outputPath+os.sep+baseModel)
 
         # supervised method
         plainSupervised(path,pathUnlabelled,learn,confidence)
@@ -43,7 +43,7 @@ def pureDistillation(baseModel, targetModel, path, pathUnlabelled, outputPath, b
 
         # Train base learner
         learn2.fine_tune(50, freeze_epochs=2)
-        learn2.save(outputPath+os.sep+targetModel)
+        learn2.export(outputPath+os.sep+targetModel)
         shutil.rmtree(path+'_tmp')
 
 
